@@ -8,9 +8,11 @@ function __autoload($className) {
 	global $wgAutoloadClasses;
 
 	static $localClasses = array(
+		# Includes
 		'AjaxDispatcher' => 'includes/AjaxDispatcher.php',
 		'AjaxCachePolicy' => 'includes/AjaxFunctions.php',
 		'AjaxResponse' => 'includes/AjaxResponse.php',
+		'AlphabeticPager' => 'includes/Pager.php',
 		'Article' => 'includes/Article.php',
 		'AuthPlugin' => 'includes/AuthPlugin.php',
 		'BagOStuff' => 'includes/BagOStuff.php',
@@ -39,9 +41,8 @@ function __autoload($className) {
 		'Database' => 'includes/Database.php',
 		'DatabaseMysql' => 'includes/Database.php',
 		'ResultWrapper' => 'includes/Database.php',
-		'OracleBlob' => 'includes/DatabaseOracle.php',
-		'DatabaseOracle' => 'includes/DatabaseOracle.php',
 		'DatabasePostgres' => 'includes/DatabasePostgres.php',
+		'DatabaseOracle' => 'includes/DatabaseOracle.php',
 		'DateFormatter' => 'includes/DateFormatter.php',
 		'DifferenceEngine' => 'includes/DifferenceEngine.php',
 		'_DiffOp' => 'includes/DifferenceEngine.php',
@@ -95,6 +96,7 @@ function __autoload($className) {
 		'HTMLCacheUpdateJob' => 'includes/HTMLCacheUpdate.php',
 		'Http' => 'includes/HttpFunctions.php',
 		'Image' => 'includes/Image.php',
+		'ArchivedFile' => 'includes/Image.php',
 		'IP' => 'includes/IP.php',
 		'ThumbnailImage' => 'includes/Image.php',
 		'ImageGallery' => 'includes/ImageGallery.php',
@@ -114,6 +116,10 @@ function __autoload($className) {
 		'MacBinary' => 'includes/MacBinary.php',
 		'MagicWord' => 'includes/MagicWord.php',
 		'MathRenderer' => 'includes/Math.php',
+		'MediaTransformOutput' => 'includes/MediaTransformOutput.php',
+		'ThumbnailImage' => 'includes/MediaTransformOutput.php',
+		'MediaTransformError' => 'includes/MediaTransformOutput.php',
+		'TransformParameterError' => 'includes/MediaTransformOutput.php',
 		'MessageCache' => 'includes/MessageCache.php',
 		'MimeMagic' => 'includes/MimeMagic.php',
 		'Namespace' => 'includes/Namespace.php',
@@ -124,16 +130,18 @@ function __autoload($className) {
 		'ReverseChronologicalPager' => 'includes/Pager.php',
 		'TablePager' => 'includes/Pager.php',
 		'Parser' => 'includes/Parser.php',
-		'ParserOutput' => 'includes/Parser.php',
-		'ParserOptions' => 'includes/Parser.php',
+		'ParserOutput' => 'includes/ParserOutput.php',
+		'ParserOptions' => 'includes/ParserOptions.php',
 		'ParserCache' => 'includes/ParserCache.php',
+		'PatrolLog' => 'includes/PatrolLog.php',
 		'ProfilerSimple' => 'includes/ProfilerSimple.php',
 		'ProfilerSimpleUDP' => 'includes/ProfilerSimpleUDP.php',
 		'Profiler' => 'includes/Profiler.php',
 		'ProxyTools' => 'includes/ProxyTools.php',
 		'ProtectionForm' => 'includes/ProtectionForm.php',
 		'QueryPage' => 'includes/QueryPage.php',
-		'PageQueryPage' => 'includes/QueryPage.php',
+		'PageQueryPage' => 'includes/PageQueryPage.php',
+		'ImageQueryPage' => 'includes/ImageQueryPage.php',
 		'RawPage' => 'includes/RawPage.php',
 		'RecentChange' => 'includes/RecentChange.php',
 		'Revision' => 'includes/Revision.php',
@@ -148,6 +156,7 @@ function __autoload($className) {
 		'SearchPostgres' => 'includes/SearchPostgres.php',
 		'SearchUpdate' => 'includes/SearchUpdate.php',
 		'SearchUpdateMyISAM' => 'includes/SearchUpdate.php',
+		'SearchOracle' => 'includes/SearchOracle.php',
 		'SiteConfiguration' => 'includes/SiteConfiguration.php',
 		'SiteStats' => 'includes/SiteStats.php',
 		'SiteStatsUpdate' => 'includes/SiteStats.php',
@@ -160,7 +169,6 @@ function __autoload($className) {
 		'IPBlockForm' => 'includes/SpecialBlockip.php',
 		'SpecialBookSources' => 'includes/SpecialBooksources.php',
 		'BrokenRedirectsPage' => 'includes/SpecialBrokenRedirects.php',
-		'CategoriesPage' => 'includes/SpecialCategories.php',
 		'EmailConfirmation' => 'includes/SpecialConfirmemail.php',
 		'ContributionsPage' => 'includes/SpecialContributions.php',
 		'DeadendPagesPage' => 'includes/SpecialDeadendpages.php',
@@ -173,7 +181,6 @@ function __autoload($className) {
 		'ImportStreamSource' => 'includes/SpecialImport.php',
 		'IPUnblockForm' => 'includes/SpecialIpblocklist.php',
 		'ListredirectsPage' => 'includes/SpecialListredirects.php',
-		'ListUsersPage' => 'includes/SpecialListusers.php',
 		'DBLockForm' => 'includes/SpecialLockdb.php',
 		'LogReader' => 'includes/SpecialLog.php',
 		'LogViewer' => 'includes/SpecialLog.php',
@@ -185,6 +192,7 @@ function __autoload($className) {
 		'MostlinkedPage' => 'includes/SpecialMostlinked.php',
 		'MostlinkedCategoriesPage' => 'includes/SpecialMostlinkedcategories.php',
 		'MostrevisionsPage' => 'includes/SpecialMostrevisions.php',
+		'FewestrevisionsPage' => 'includes/SpecialFewestrevisions.php',
 		'MovePageForm' => 'includes/SpecialMovepage.php',
 		'NewbieContributionsPage' => 'includes/SpecialNewbieContributions.php',
 		'NewPagesPage' => 'includes/SpecialNewpages.php',
@@ -194,6 +202,7 @@ function __autoload($className) {
 		'PopularPagesPage' => 'includes/SpecialPopularpages.php',
 		'PreferencesForm' => 'includes/SpecialPreferences.php',
 		'SpecialPrefixindex' => 'includes/SpecialPrefixindex.php',
+		'PasswordResetForm' => 'includes/SpecialResetpass.php',
 		'RevisionDeleteForm' => 'includes/SpecialRevisiondelete.php',
 		'RevisionDeleter' => 'includes/SpecialRevisiondelete.php',
 		'SpecialSearch' => 'includes/SpecialSearch.php',
@@ -215,6 +224,7 @@ function __autoload($className) {
 		'WantedCategoriesPage' => 'includes/SpecialWantedcategories.php',
 		'WantedPagesPage' => 'includes/SpecialWantedpages.php',
 		'WhatLinksHerePage' => 'includes/SpecialWhatlinkshere.php',
+		'WithoutInterwikiPage' => 'includes/SpecialWithoutinterwiki.php',
 		'SquidUpdate' => 'includes/SquidUpdate.php',
 		'ReplacementArray' => 'includes/StringUtils.php',
 		'Replacer' => 'includes/StringUtils.php',
@@ -237,13 +247,27 @@ function __autoload($className) {
 		'Xml' => 'includes/Xml.php',
 		'ZhClient' => 'includes/ZhClient.php',
 		'memcached' => 'includes/memcached-client.php',
+
+		# Media
+		'BitmapHandler' => 'includes/media/Bitmap.php',
+		'BmpHandler' => 'includes/media/BMP.php',
+		'DjVuHandler' => 'includes/media/DjVu.php',
+		'MediaHandler' => 'includes/media/Generic.php',
+		'ImageHandler' => 'includes/media/Generic.php',
+		'SvgHandler' => 'includes/media/SVG.php',
+
+		# Normal
 		'UtfNormal' => 'includes/normal/UtfNormal.php',
+
+		# Templates
 		'UsercreateTemplate' => 'includes/templates/Userlogin.php',
 		'UserloginTemplate' => 'includes/templates/Userlogin.php',
-		'Language' => 'languages/Language.php',
-		'PasswordResetForm' => 'includes/SpecialResetpass.php',
 
-		// API classes
+		# Languages
+		'Language' => 'languages/Language.php',
+		'RandomPage' => 'includes/SpecialRandompage.php',
+
+		# API
 		'ApiBase' => 'includes/api/ApiBase.php',
 		'ApiFormatFeedWrapper' => 'includes/api/ApiFormatBase.php',
 		'ApiFeedWatchlist' => 'includes/api/ApiFeedWatchlist.php',
@@ -274,6 +298,7 @@ function __autoload($className) {
 		'ApiResult' => 'includes/api/ApiResult.php',
 	);
 	
+	wfProfileIn( __METHOD__ );
 	if ( isset( $localClasses[$className] ) ) {
 		$filename = $localClasses[$className];
 	} elseif ( isset( $wgAutoloadClasses[$className] ) ) {
@@ -290,6 +315,7 @@ function __autoload($className) {
 		}
 		if ( !$filename ) {
 			# Give up
+			wfProfileOut( __METHOD__ );
 			return;
 		}
 	}
@@ -300,6 +326,7 @@ function __autoload($className) {
 		$filename = "$IP/$filename";
 	}
 	require( $filename );
+	wfProfileOut( __METHOD__ );
 }
 
 function wfLoadAllExtensions() {
@@ -311,10 +338,10 @@ function wfLoadAllExtensions() {
 	# guaranteed by entering special pages via SpecialPage members such as 
 	# executePath(), but here we have to take a more explicit measure.
 	
-	require_once( 'SpecialPage.php' );
+	require_once( dirname(__FILE__) . '/SpecialPage.php' );
 	
 	foreach( $wgAutoloadClasses as $class => $file ) {
-		if ( ! class_exists( $class ) ) {
+		if( !( class_exists( $class ) || interface_exists( $class ) ) ) {
 			require( $file );
 		}
 	}
