@@ -1,6 +1,5 @@
 <?php
-# Basic support for outputting syndication feeds in RSS, other formats
-#
+
 # Copyright (C) 2004 Brion Vibber <brion@pobox.com>
 # http://www.mediawiki.org/
 #
@@ -20,15 +19,13 @@
 # http://www.gnu.org/copyleft/gpl.html
 
 /**
+ * Basic support for outputting syndication feeds in RSS, other formats.
  * Contain a feed class as well as classes to build rss / atom ... feeds
  * Available feeds are defined in Defines.php
- * @package MediaWiki
  */
 
-
 /**
- * @todo document
- * @package MediaWiki
+ * A base class for basic support for outputting syndication feeds in RSS and other formats.
  */
 class FeedItem {
 	/**#@+
@@ -45,7 +42,7 @@ class FeedItem {
 	/**#@+
 	 * @todo document
 	 */
-	function FeedItem( $Title, $Description, $Url, $Date = '', $Author = '', $Comments = '' ) {
+	function __construct( $Title, $Description, $Url, $Date = '', $Author = '', $Comments = '' ) {
 		$this->Title = $Title;
 		$this->Description = $Description;
 		$this->Url = $Url;
@@ -77,8 +74,7 @@ class FeedItem {
 }
 
 /**
- * @todo document
- * @package MediaWiki
+ * @todo document (needs one-sentence top-level class description).
  */
 class ChannelFeed extends FeedItem {
 	/**#@+
@@ -160,8 +156,6 @@ class ChannelFeed extends FeedItem {
 
 /**
  * Generate a RSS feed
- * @todo document
- * @package MediaWiki
  */
 class RSSFeed extends ChannelFeed {
 
@@ -221,8 +215,6 @@ class RSSFeed extends ChannelFeed {
 
 /**
  * Generate an Atom feed
- * @todo document
- * @package MediaWiki
  */
 class AtomFeed extends ChannelFeed {
 	/**
