@@ -3,13 +3,12 @@
 /**
  * Special page to allow managing user group membership
  *
- * @package MediaWiki
- * @subpackage Special pages
+ * @addtogroup SpecialPage
  * @todo This code is disgusting and needs a total rewrite
  */
 
 /** */
-require_once('HTMLForm.php');
+require_once( dirname(__FILE__) . '/HTMLForm.php');
 
 /** Entry point */
 function wfSpecialUserrights() {
@@ -20,8 +19,7 @@ function wfSpecialUserrights() {
 
 /**
  * A class to manage user levels rights.
- * @package MediaWiki
- * @subpackage SpecialPage
+ * @addtogroup SpecialPage
  */
 class UserrightsForm extends HTMLForm {
 	var $mPosted, $mRequest, $mSaveprefs;
@@ -55,10 +53,12 @@ class UserrightsForm extends HTMLForm {
 			if( $this->mRequest->getCheck( 'saveusergroups' ) ) {
 				global $wgUser;
 				$username = $this->mRequest->getVal( 'user-editname' );
+				$reason = $this->mRequest->getVal( 'user-reason' );
 				if( $wgUser->matchEditToken( $this->mRequest->getVal( 'wpEditToken' ), $username ) ) {
 					$this->saveUserGroups( $username,
 						$this->mRequest->getArray( 'member' ),
-						$this->mRequest->getArray( 'available' ) );
+						$this->mRequest->getArray( 'available' ),
+						$reason );
 				}
 			}
 		}
@@ -71,9 +71,10 @@ class UserrightsForm extends HTMLForm {
 	 * @param string $username Username to apply changes to.
 	 * @param array $removegroup id of groups to be removed.
 	 * @param array $addgroup id of groups to be added.
+	 * @param string $reason Reason for group change
 	 *
 	 */
-	function saveUserGroups( $username, $removegroup, $addgroup) {
+	function saveUserGroups( $username, $removegroup, $addgroup, $reason ) {
 		global $wgOut;
 		$u = User::newFromName($username);
 
@@ -109,7 +110,7 @@ class UserrightsForm extends HTMLForm {
 
 		wfRunHooks( 'UserRights', array( &$u, $addgroup, $removegroup ) );	
 		$log = new LogPage( 'rights' );
-		$log->addEntry( 'rights', Title::makeTitle( NS_USER, $u->getName() ), '', array( $this->makeGroupNameList( $oldGroups ),
+		$log->addEntry( 'rights', Title::makeTitle( NS_USER, $u->getName() ), $reason, array( $this->makeGroupNameList( $oldGroups ),
 			$this->makeGroupNameList( $newGroups ) ) );
 	}
 
@@ -137,7 +138,7 @@ class UserrightsForm extends HTMLForm {
 	 * @param string $username Name of the user.
 	 */
 	function editUserGroupsForm($username) {
-		global $wgOut, $wgUser;
+		global $wgOut;
 
 		$user = User::newFromName($username);
 		if( is_null( $user ) ) {
@@ -149,30 +150,52 @@ class UserrightsForm extends HTMLForm {
 		}
 
 		$groups = $user->getGroups();
-
-		$wgOut->addHTML( "<form name=\"editGroup\" action=\"$this->action\" method=\"post\">\n".
-			wfElement( 'input', array(
-				'type'  => 'hidden',
-				'name'  => 'user-editname',
-				'value' => $username ) ) .
-			wfElement( 'input', array(
-				'type'  => 'hidden',
-				'name'  => 'wpEditToken',
-				'value' => $wgUser->editToken( $username ) ) ) .
-			$this->fieldset( 'editusergroup',
-			$wgOut->parse( wfMsg('editinguser', $username ) ) .
-			'<table border="0" align="center"><tr><td>'.
-			HTMLSelectGroups('member', $this->mName.'-groupsmember', $groups,true,6).
-			'</td><td>'.
-			HTMLSelectGroups('available', $this->mName.'-groupsavailable', $groups,true,6,true).
-			'</td></tr></table>'."\n".
-			$wgOut->parse( wfMsg('userrights-groupshelp') ) .
-			wfElement( 'input', array(
-				'type'  => 'submit',
-				'name'  => 'saveusergroups',
-				'value' => wfMsg( 'saveusergroups' ) ) )
-			));
-		$wgOut->addHTML( "</form>\n" );
+		$this->showEditUserGroupsForm( $username, $groups );
+	}
+	
+	function showEditUserGroupsForm( $username, $groups ) {
+		global $wgOut, $wgUser;
+		$wgOut->addHTML(
+			Xml::openElement( 'form', array( 'method' => 'post', 'action' => $this->action, 'name' => 'editGroup' ) ) .
+			Xml::hidden( 'user-editname', $username ) .
+			Xml::hidden( 'wpEditToken', $wgUser->editToken( $username ) ) .
+			Xml::openElement( 'fieldset' ) .
+			Xml::element( 'legend', array(), wfMsg( 'userrights-editusergroup' ) ) .
+			$wgOut->parse( wfMsg( 'editinguser', $username ) ) .
+			"<table border='0'>
+			<tr>
+				<td></td>
+				<td>
+				<table width='400'>
+					<tr>
+						<td width='50%'>" . HTMLSelectGroups( 'member', $this->mName.'-groupsmember', $groups, true, 6 ) . "</td>
+						<td width='50%'>" . HTMLSelectGroups( 'available', $this->mName.'-groupsavailable', $groups, true, 6, true) . "</td>
+					</tr>
+				</table>
+			</tr>
+			<tr>
+				<td colspan='2'>" .
+					$wgOut->parse( wfMsg('userrights-groupshelp') ) .
+				"</td>
+			</tr>
+			<tr>
+				<td>" .
+					Xml::label( wfMsg( 'userrights-reason' ), 'wpReason' ) .
+				"</td>
+				<td>" .
+					Xml::input( 'user-reason', 60, false, array( 'id' => 'wpReason' ) ) .
+				"</td>
+			</tr>
+			<tr>
+				<td></td>
+				<td>" .
+				Xml::submitButton( wfMsg( 'saveusergroups' ), array( 'name' => 'saveusergroups' ) ) .
+				"</td>
+			</tr>
+			</table>\n" .
+			Xml::closeElement( 'fieldset' ) .
+			Xml::closeElement( 'form' ) . "\n"
+		);
 	}
 } // end class UserrightsForm
 ?>
