@@ -1,8 +1,7 @@
 <?php
 /** French (Français)
  *
- * @package MediaWiki
- * @subpackage Language
+ * @addtogroup Language
  *
  */
 
@@ -10,7 +9,7 @@ class LanguageFr extends Language {
 	/**
 	 * Use singular form for zero (see bug 7309)
 	 */
-        function convertPlural( $count, $w1, $w2, $w3) {
+        function convertPlural( $count, $w1, $w2, $w3, $w4, $w5) {
 		return $count <= '1' ? $w1 : $w2;
         }
 }
