@@ -1,8 +1,7 @@
 <?php
 /** Dutch Lower Saxon (Nedersaksisch)
   *
-  * @package MediaWiki
-  * @subpackage Language
+  * @addtogroup Language
   *
   * @author Ævar Arnfjörð Bjarmason <avarab@gmail.com>, Jens Frank
   * @copyright Copyright © 2005, Ævar Arnfjörð Bjarmason, Jens Frank
@@ -34,8 +33,8 @@ $namespaceNames = array(
 	NS_MEDIAWIKI_TALK   => 'Overleg_MediaWiki',
 	NS_TEMPLATE         => 'Sjabloon',
 	NS_TEMPLATE_TALK    => 'Overleg_sjabloon',
-	NS_HELP             => 'Help',
-	NS_HELP_TALK        => 'Overleg_help',
+	NS_HELP             => 'Hulpe',
+	NS_HELP_TALK        => 'Overleg_hulpe',
 	NS_CATEGORY         => 'Kattegerie',
 	NS_CATEGORY_TALK    => 'Overleg_kattegerie'
 );
@@ -44,6 +43,7 @@ $namespaceAliases = array(
 	'Speciaol'          => NS_SPECIAL,
 	'Categorie'         => NS_CATEGORY,
 	'Overleg_categorie' => NS_CATEGORY_TALK,
+	'Overleg_help'      => NS_HELP_TALK,
 );
 
 $dateFormats = array(
